<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Hienosäätö</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="558"/>
        <location filename="../defaultlook.cpp" line="565"/>
        <location filename="../defaultlook.cpp" line="582"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>MX Tweak</source>
        <translation>MX Hienosäätö</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Xfce:n asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mukauta paneelia&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="77"/>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Paneeli</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Varmuuskopioi nykyinen paneelin konfiguraatio</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Palauta paneelin konfiguraatio varmuuskopiosta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Palauta oletuspaneeli</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Vaikuttaa ensimmäiseen paneeliin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Näytä paneeli pystytasossa</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Alareuna</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Yläreuna</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Näytä paneeli vaakatasossa</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Vasen reuna</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Oikea reuna</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vaikuttaa kaikkiin paneeleihin&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ikkunapainikkeet&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="446"/>
        <location filename="../defaultlook.ui" line="549"/>
        <location filename="../defaultlook.ui" line="740"/>
        <location filename="../defaultlook.ui" line="877"/>
        <location filename="../defaultlook.ui" line="1000"/>
        <location filename="../defaultlook.ui" line="1007"/>
        <location filename="../defaultlook.ui" line="1099"/>
        <location filename="../defaultlook.ui" line="1168"/>
        <source>Apply</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Ulkoasun asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Muunna verkkosivujen lomakkeet käytettässä tummaa ulkoasua</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="614"/>
        <location filename="../defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Käynnistä compton-conf konfigurointityökalut</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Comptonin asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm:n asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Muokkaa compton.conf -tiedostoa suoraan tekstieditorissa</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Muokkaa compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Läpinäkyvyyden ja varjostuksen asetukset</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>automaattinen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="800"/>
        <source>off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1016"/>
        <source>Config Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1024"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1031"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1045"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1052"/>
        <source>Use tearfree amdgpu option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1059"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1066"/>
        <source>Use tearfree radeon driver option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1073"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="811"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="836"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="843"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="870"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="913"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="920"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="927"/>
        <location filename="../defaultlook.ui" line="941"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="934"/>
        <source>GTK scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="961"/>
        <source>xrandr Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1135"/>
        <source>Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1155"/>
        <source>Show systray (notification area) frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1179"/>
        <source>Show windows from all workspaces in panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1186"/>
        <source>Enable single-click on desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1193"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1241"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1248"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1200"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1207"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1128"/>
        <source>Password for administrative tasks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1227"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="557"/>
        <source>About MX Tweak</source>
        <translation>Tietoja MX Tweakista</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="558"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="559"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="561"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="562"/>
        <location filename="../defaultlook.cpp" line="565"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="563"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="594"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="746"/>
        <source>Panel settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="747"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1157"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1494"/>
        <source>Choose a theme set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Ikkunapainikkeet</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ulkoasu&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Näytä painikkeiden kuvaukset</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Näytä tasaiset painikkeet</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Näytä kahva</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Lajittelujärjestys:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Aikaleima</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Ryhmitä otsikko ja aikaleima</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Ikkunan otsikko</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Ryhmitä otsikko ja ikkunan otsikko</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ei mitään, salli veto ja pudotus</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Käytös&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Ikkunoiden ryhmitys:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Aina</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Keskimmäisen näppäimen toiminto:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Sulje ikkuna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Pienennä ikkuna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Palauta pienennetyt ikkunat nykyiseen työtilaan</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Piirrä ikkunan reunus kun osoite on painikkeen päällä</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Vaihda ikkunoita käyttäen hiiren rullaa</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Suodatus&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Näytä ikkunat kaikista työtiloista tai näkymistä</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Näytä vain pienennetyt ikkunat</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Näytä ikkunat kaikista näytöistä</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Näytä varjot ikkunoiden alla</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Näytä varjot tavallisten ikkunoiden alla</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
